@@ -23,58 +23,55 @@
  * Share and enjoy!  :-)        http://www.isthe.com/chongo/tech/comp/calc/
  */
 
-
 #if !defined(INCLUDE_ALLOC_H)
-#define INCLUDE_ALLOC_H
+#  define INCLUDE_ALLOC_H
 
+#  if defined(CALC_SRC) /* if we are building from the calc source tree */
+#    include "decl.h"
+#    include "have_newstr.h"
+#    include "have_string.h"
+#    include "have_const.h"
+#  else
+#    include <calc/decl.h>
+#    include <calc/have_newstr.h>
+#    include <calc/have_string.h>
+#    include <calc/have_const.h>
+#  endif
 
-#if defined(CALC_SRC)   /* if we are building from the calc source tree */
-# include "decl.h"
-# include "have_newstr.h"
-# include "have_string.h"
-# include "have_const.h"
-#else
-# include <calc/decl.h>
-# include <calc/have_newstr.h>
-# include <calc/have_string.h>
-# include <calc/have_const.h>
-#endif
+#  ifdef HAVE_STRING_H
+#    include <string.h>
 
-#ifdef HAVE_STRING_H
-# include <string.h>
+#  else
+#    include <stdio.h>
 
-#else
-#include <stdio.h>
-
-# if defined(HAVE_NEWSTR)
+#    if defined(HAVE_NEWSTR)
 E_FUNC void *memcpy();
 E_FUNC void *memset();
-#if defined(FORCE_STDC) || \
-   (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
+#      if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
 E_FUNC size_t strlen();
-#  else
+#      else
 E_FUNC long strlen();
-#  endif
-# else /* HAVE_NEWSTR */
+#      endif
+#    else  /* HAVE_NEWSTR */
 E_FUNC void bcopy();
 E_FUNC void bfill();
 E_FUNC char *index();
-# endif /* HAVE_NEWSTR */
+#    endif /* HAVE_NEWSTR */
 E_FUNC char *strchr();
 E_FUNC char *strcpy();
 E_FUNC char *strncpy();
 E_FUNC char *strcat();
 E_FUNC int strcmp();
 
-#endif
+#  endif
 
-#if !defined(HAVE_NEWSTR)
-#undef memcpy
-#define memcpy(s1, s2, n) bcopy(s2, s1, n)
-#undef memset
-#define memset(s, c, n) bfill(s, n, c)
-#undef strchr
-#define strchr(s, c) index(s, c)
-#endif /* HAVE_NEWSTR */
+#  if !defined(HAVE_NEWSTR)
+#    undef memcpy
+#    define memcpy(s1, s2, n) bcopy(s2, s1, n)
+#    undef memset
+#    define memset(s, c, n) bfill(s, n, c)
+#    undef strchr
+#    define strchr(s, c) index(s, c)
+#  endif /* HAVE_NEWSTR */
 
 #endif /* !INCLUDE_ALLOC_H */
